@@ -7,8 +7,8 @@ import (
 	"github.com/gotidy/ptr"
 	"github.com/stretchr/testify/assert"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/elbv2"
+	"github.com/aws/aws-sdk-go/aws"           //nolint:staticcheck
+	"github.com/aws/aws-sdk-go/service/elbv2" //nolint:staticcheck
 )
 
 func Test_ELBv2LoadBalancer_Properties(t *testing.T) {
