@@ -4,12 +4,11 @@ import (
 	"context"
 	"testing"
 
-	"github.com/gotidy/ptr"
-
 	"github.com/golang/mock/gomock"
+	"github.com/gotidy/ptr"
 	"github.com/stretchr/testify/assert"
 
-	"github.com/aws/aws-sdk-go/service/iam"
+	"github.com/aws/aws-sdk-go/service/iam" //nolint:staticcheck
 
 	"github.com/ekristen/aws-nuke/v3/mocks/mock_iamiface"
 )
