@@ -2,14 +2,13 @@ package resources
 
 import (
 	"context"
-
 	"testing"
 
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/assert"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/iam"
+	"github.com/aws/aws-sdk-go/aws"         //nolint:staticcheck
+	"github.com/aws/aws-sdk-go/service/iam" //nolint:staticcheck
 
 	"github.com/ekristen/aws-nuke/v3/mocks/mock_iamiface"
 )
